@@ -2,11 +2,12 @@ import os
 
 
 def print_default_config(is_quiet=False):
+    """  """
     if not is_quiet:
         parent_dir = os.path.dirname(__file__)
         pkg_root = os.path.join(parent_dir, "..")
         default_config_filename = os.path.join(pkg_root, "data", ".howfairis.yml")
-        with open(default_config_filename, "rt") as f:
-            text = f.read()
-        print(text, end='')
+        with open(default_config_filename, "rt") as fid:
+            text = fid.read()
+        print(text, end="")
     return 0
